#mock-api

This module is a connect-compatible middleware generating function that generates an API based on a Swagger 2.0 compatible YAML file. All data returned is generated by [chance](http://chancejs.com/).

## installation

The primary use case is to be run as a middleware for [grunt-contrib-connect](https://github.com/gruntjs/grunt-contrib-connect). Run the following command:

`npm install swagger-mock-api`

## Using the middleware

Assuming the API is to be run from a `grunt` task, ensure the following module has also been installed via npm:

* grunt-contrib-connect

If you're not auto-loading grunt tasks, find in your Gruntfile where the tasks are being loaded and add the line:

`grunt.loadNpmTasks('grunt-contrib-connect');`

Then, configure a task like so:

```javascript

var path = require('path');
var mockApi = require('path to mockApi');

grunt.initConfig({
  connect: {
    server: {
      options: {
        middleware: [
          mockApi({
                yamlPath: path.join(__dirname, 'relative path to swagger yaml file')
            })
        ],
      },
    },
  },
});
```

## Specifying custom Chance options

Swagger specifies only a few primitive types; for scenarios where specific chance methods are needed, use the `x-chance-type` field.

```yaml
...
definitions:
  NewPet:
    properties:
      name:
        type: string
        x-chance-type: name
      tag:
        type: string
        x-chance-type: guid
```


Most of the chance methods allow some fine-tuning of the returned data.  For example, the [integer](http://chancejs.com/#integer) method allows specification of minimum and maximum output values.  These options can be configured in the Swagger YAML file with the `x-chance-options` block:

```yaml
...
definitions:
  Pet:
    allOf:
      - $ref: '#/definitions/NewPet'
      - required:
        - id
        properties:
          id:
            type: integer
            format: int64
            x-type-options:
              min: 1
              max: 1000
```


## Todos:

* Test with more complex swagger files
* Actual unit tests
* Convert code to utilize ES6 features and clean up codebase
